@@ -381,12 +381,16 @@ def is_py2_stdlib_module(m):
     Tries to infer whether the module m is from the Python 2 standard library.
     This may not be reliable on all systems.
     """
+    if utils.PY3:
+        return False
     if not 'stdlib_path' in is_py2_stdlib_module.__dict__:
         stdlib_files = [contextlib.__file__, os.__file__, copy.__file__]
         stdlib_paths = [os.path.split(f)[0] for f in stdlib_files]
         if not len(set(stdlib_paths)) == 1:
-            raise RuntimeError('Could not determine the location of the Python '
-                               'standard library')
+            # This seems to happen on travis-ci.org. Very strange. We'll try to
+            # ignore it.
+            logging.warn('Multiple locations found for the Python standard '
+                         'library: %s' % stdlib_paths)
         # They are identical, so choose one and add / so we don't match urllib2
         is_py2_stdlib_module.stdlib_path = stdlib_paths[0] + os.sep
 
@@ -415,7 +419,7 @@ def scrub_py2_sys_modules():
         module = sys.modules[modulename]
 
         if is_py2_stdlib_module(module):
-            logging.debug('Deleting {} from sys.modules'.format(modulename))
+            logging.debug('Deleting {0} from sys.modules'.format(modulename))
             del sys.modules[modulename]
 
 
@@ -432,7 +436,7 @@ def scrub_future_sys_modules():
             if (modulename in RENAMES.values() or    # builtins, configparser etc.
                 (hasattr(module, '__file__') and
                  module.__file__.startswith(future_stdlib))):
-                logging.debug('Deleting {} from sys.modules'.format(modulename))
+                logging.debug('Deleting {0} from sys.modules'.format(modulename))
                 del sys.modules[modulename]
 
 
@@ -474,7 +478,7 @@ def install_hooks(keep_sys_modules=False):
         return
     if not keep_sys_modules:
         scrub_py2_sys_modules()    # in case they interfere ... e.g. urllib
-    logging.debug('sys.meta_path was: {}'.format(sys.meta_path))
+    logging.debug('sys.meta_path was: {0}'.format(sys.meta_path))
     logging.debug('Installing hooks ...')
 
     for (newmodname, newobjname, oldmodname, oldobjname) in MOVES:
@@ -487,7 +491,7 @@ def install_hooks(keep_sys_modules=False):
     newhook = RenameImport(RENAMES)
     if not detect_hooks():
         sys.meta_path.append(newhook)
-    logging.debug('sys.meta_path is now: {}'.format(sys.meta_path))
+    logging.debug('sys.meta_path is now: {0}'.format(sys.meta_path))
 
 
 def enable_hooks():
