@@ -1,9 +1,8 @@
 """HTTP/1.1 client library
 
-From Python 3.3
+A backport of the Python 3.3 module to Python 2.7 using ``future``.
 
-<intro stuff goes here>
-<other stuff, too>
+--------------
 
 HTTPConnection goes through a number of "states", which define when a client
 may legally make another request or fetch the response for a particular
@@ -71,6 +70,7 @@ Req-sent-unread-response       _CS_REQ_SENT       <response_class>
 from __future__ import (absolute_import, division,
                         print_function, unicode_literals)
 from future.builtins import *
+from future.utils import isbytes, istext
 
 import email.parser
 import email.message
@@ -82,8 +82,10 @@ import collections
 # from urllib.parse import urlsplit
 # Use the Py2.7 equivalent:
 from urlparse import urlsplit
-from array import array
+
 import warnings
+import numbers
+from array import array
 
 __all__ = ["HTTPResponse", "HTTPConnection",
            "HTTPException", "NotConnected", "UnknownProtocol",
@@ -703,7 +705,7 @@ class HTTPResponse(io.RawIOBase, object):
         if self.headers is None:
             raise ResponseNotReady()
         headers = self.headers.get_all(name) or default
-        if isinstance(headers, str) or not hasattr(headers, '__iter__'):
+        if istext(headers) or not hasattr(headers, '__iter__'):
             return headers
         else:
             return ', '.join(headers)
@@ -909,7 +911,7 @@ class HTTPConnection(object):
         # If msg and message_body are sent in a single send() call,
         # it will avoid performance problems caused by the interaction
         # between delayed ack and the Nagle algorithm.
-        if isinstance(message_body, bytes):
+        if isbytes(message_body):
             msg += message_body
             message_body = None
         self.send(msg)
@@ -1048,7 +1050,7 @@ class HTTPConnection(object):
         for i, one_value in enumerate(values):
             if hasattr(one_value, 'encode'):
                 values[i] = one_value.encode('latin-1')
-            elif isinstance(one_value, int):
+            elif isinstance(one_value, numbers.Integral):
                 values[i] = str(one_value).encode('ascii')
         value = bytes(b'\r\n\t').join(values)
         header = header + b': ' + value
@@ -1105,7 +1107,7 @@ class HTTPConnection(object):
             self._set_content_length(body)
         for hdr, value in headers.items():
             self.putheader(hdr, value)
-        if isinstance(body, str):
+        if istext(body):
             # RFC 2616 Section 3.7.1 says that text default has a
             # default charset of iso-8859-1.
             body = body.encode('iso-8859-1')
@@ -1200,59 +1202,6 @@ else:
     __all__.append("HTTPSConnection")
 
 
-    ######################################
-    # class HTTPSConnection(HTTPConnection):
-    #     "This class allows communication via SSL."
-
-    #     default_port = HTTPS_PORT
-
-    #     # XXX Should key_file and cert_file be deprecated in favour of context?
-
-    #     def __init__(self, host, port=None, key_file=None, cert_file=None,
-    #                  strict=_strict_sentinel, timeout=socket._GLOBAL_DEFAULT_TIMEOUT,
-    #                  source_address=None, context=None, check_hostname=None):
-    #         super(HTTPSConnection, self).__init__(host, port, strict, timeout,
-    #                                               source_address)
-    #         self.key_file = key_file
-    #         self.cert_file = cert_file
-    #         if context is None:
-    #             # Some reasonable defaults
-    #             context = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
-    #             context.options |= ssl.OP_NO_SSLv2
-    #         will_verify = context.verify_mode != ssl.CERT_NONE
-    #         if check_hostname is None:
-    #             check_hostname = will_verify
-    #         elif check_hostname and not will_verify:
-    #             raise ValueError("check_hostname needs a SSL context with "
-    #                              "either CERT_OPTIONAL or CERT_REQUIRED")
-    #         if key_file or cert_file:
-    #             context.load_cert_chain(cert_file, key_file)
-    #         self._context = context
-    #         self._check_hostname = check_hostname
-
-    #     def connect(self):
-    #         "Connect to a host on a given (SSL) port."
-
-    #         sock = socket.create_connection((self.host, self.port),
-    #                                         self.timeout, self.source_address)
-
-    #         if self._tunnel_host:
-    #             self.sock = sock
-    #             self._tunnel()
-
-    #         server_hostname = self.host if ssl.HAS_SNI else None
-    #         self.sock = self._context.wrap_socket(sock,
-    #                                               server_hostname=server_hostname)
-    #         try:
-    #             if self._check_hostname:
-    #                 ssl.match_hostname(self.sock.getpeercert(), self.host)
-    #         except Exception:
-    #             self.sock.shutdown(socket.SHUT_RDWR)
-    #             self.sock.close()
-    #             raise
-
-    # __all__.append("HTTPSConnection")
-
 class HTTPException(Exception):
     # Subclasses that define an __init__ must call Exception.__init__
     # or define self.args.  Otherwise, str() will fail.
